pub struct Client { /* private fields */ }Expand description
A read-only registry client.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new(config: ClientConfig) -> Self
pub fn new(config: ClientConfig) -> Self
Returns a new client with the given ClientConfig.
Sourcepub fn from_default_config_file() -> Result<Option<Self>, Error>
pub fn from_default_config_file() -> Result<Option<Self>, Error>
Returns a new client configured from the default config file path. Returns Ok(None) if the default config file does not exist.
Sourcepub async fn list_all_versions(
&mut self,
package: &PackageRef,
) -> Result<Vec<Version>, Error>
pub async fn list_all_versions( &mut self, package: &PackageRef, ) -> Result<Vec<Version>, Error>
Returns a list of all package Versions available for the given package.
Sourcepub async fn get_release(
&mut self,
package: &PackageRef,
version: &Version,
) -> Result<Release, Error>
pub async fn get_release( &mut self, package: &PackageRef, version: &Version, ) -> Result<Release, Error>
Returns a Release for the given package version.
Sourcepub async fn stream_content(
&mut self,
package: &PackageRef,
release: &Release,
) -> Result<BoxStream<'_, Result<Bytes, Error>>, Error>
pub async fn stream_content( &mut self, package: &PackageRef, release: &Release, ) -> Result<BoxStream<'_, Result<Bytes, Error>>, Error>
Returns a BoxStream of content chunks. Contents are validated
against the given Release::content_digest.